@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2018 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2019 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -49,7 +49,7 @@ class TextEditAutoCorrectionWidget : public QTextEdit
     Q_OBJECT
 public:
     explicit TextEditAutoCorrectionWidget(PimCommon::AutoCorrection *autoCorrection, QWidget *parent = nullptr);
-    ~TextEditAutoCorrectionWidget();
+    ~TextEditAutoCorrectionWidget() override;
 
 protected:
     void keyPressEvent(QKeyEvent *e) override;
