@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2016-2018 Montel Laurent <montel@kde.org>
+  Copyright (c) 2016-2019 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
@@ -34,7 +34,7 @@ ConfigurePluginsListWidget::ConfigurePluginsListWidget(QWidget *parent)
 {
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
     mainLayout->setObjectName(QStringLiteral("mainlayout"));
-    mainLayout->setMargin(0);
+    mainLayout->setContentsMargins(0, 0, 0, 0);
 
     mListWidget = new QTreeWidget(this);
     mListWidget->setSortingEnabled(true);
@@ -112,7 +112,7 @@ void ConfigurePluginsListWidget::savePlugins(const QString &groupName, const QSt
 }
 
 void ConfigurePluginsListWidget::fillTopItems(const QVector<PimCommon::PluginUtilData> &lst, const QString &topLevelItemName, const QString &groupName, const QString &prefixKey,
-                                              QList<PluginItem *> &itemsList, const QString &configureGroupName)
+                                              QList<PluginItem *> &itemsList, const QString &configureGroupName, bool checkable)
 {
     itemsList.clear();
     if (!lst.isEmpty()) {
@@ -126,9 +126,11 @@ void ConfigurePluginsListWidget::fillTopItems(const QVector<PimCommon::PluginUti
             subItem->mDescription = data.mDescription;
             subItem->mEnableByDefault = data.mEnableByDefault;
             subItem->mHasConfigureSupport = data.mHasConfigureDialog;
-            const bool isPluginActivated = PimCommon::PluginUtil::isPluginActivated(pair.first, pair.second, data.mEnableByDefault, data.mIdentifier);
-            subItem->mEnableFromUserSettings = isPluginActivated;
-            subItem->setCheckState(0, isPluginActivated ? Qt::Checked : Qt::Unchecked);
+            if (checkable) {
+                const bool isPluginActivated = PimCommon::PluginUtil::isPluginActivated(pair.first, pair.second, data.mEnableByDefault, data.mIdentifier);
+                subItem->mEnableFromUserSettings = isPluginActivated;
+                subItem->setCheckState(0, isPluginActivated ? Qt::Checked : Qt::Unchecked);
+            }
             if (data.mHasConfigureDialog) {
                 QToolButton *but = new QToolButton(mListWidget);
                 QAction *act = new QAction(but);
