@@ -1,9 +1,10 @@
 /*
-  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2019 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -33,7 +34,17 @@ public:
     ~CustomToolsPlugin();
 
     virtual PimCommon::CustomToolsViewInterface *createView(KActionCollection *ac, CustomToolsWidgetNg *parent = nullptr) = 0;
-    virtual QString customToolName() const = 0;
+    Q_REQUIRED_RESULT virtual QString customToolName() const = 0;
+
+    Q_REQUIRED_RESULT virtual bool hasConfigureDialog() const;
+    virtual void showConfigureDialog(QWidget *parent);
+
+    void emitConfigChanged();
+
+    Q_REQUIRED_RESULT virtual QString description() const;
+
+    void setIsEnabled(bool enabled);
+    Q_REQUIRED_RESULT bool isEnabled() const;
 
 private:
     CustomToolsPluginPrivate *const d;
